# -*- coding: utf-8 -*-
# flake8: noqa
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: protos/ydb_query.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from ydb._grpc.v3.protos.annotations import validation_pb2 as protos_dot_annotations_dot_validation__pb2
from ydb._grpc.v3.protos import ydb_issue_message_pb2 as protos_dot_ydb__issue__message__pb2
from ydb._grpc.v3.protos import ydb_operation_pb2 as protos_dot_ydb__operation__pb2
from ydb._grpc.v3.protos import ydb_query_stats_pb2 as protos_dot_ydb__query__stats__pb2
from ydb._grpc.v3.protos import ydb_status_codes_pb2 as protos_dot_ydb__status__codes__pb2
from ydb._grpc.v3.protos import ydb_formats_pb2 as protos_dot_ydb__formats__pb2
from ydb._grpc.v3.protos import ydb_value_pb2 as protos_dot_ydb__value__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='protos/ydb_query.proto',
  package='Ydb.Query',
  syntax='proto3',
  serialized_options=b'\n\024tech.ydb.proto.queryZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Query\370\001\001',
  create_key=_descriptor._internal_create_key,
  serialized_pb=b'\n\x16protos/ydb_query.proto\x12\tYdb.Query\x1a\x1egoogle/protobuf/duration.proto\x1a#protos/annotations/validation.proto\x1a\x1eprotos/ydb_issue_message.proto\x1a\x1aprotos/ydb_operation.proto\x1a\x1cprotos/ydb_query_stats.proto\x1a\x1dprotos/ydb_status_codes.proto\x1a\x18protos/ydb_formats.proto\x1a\x16protos/ydb_value.proto\"\x16\n\x14\x43reateSessionRequest\"\xa3\x01\n\x15\x43reateSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\x1b\n\nsession_id\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x19\n\x07node_id\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"3\n\x14\x44\x65leteSessionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"k\n\x15\x44\x65leteSessionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"3\n\x14\x41ttachSessionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"b\n\x0cSessionState\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"\x1a\n\x18SerializableModeSettings\"6\n\x12OnlineModeSettings\x12 \n\x18\x61llow_inconsistent_reads\x18\x01 \x01(\x08\"\x13\n\x11StaleModeSettings\"\x16\n\x14SnapshotModeSettings\"\x18\n\x16SnapshotRWModeSettings\"\xdd\x02\n\x13TransactionSettings\x12\x46\n\x17serializable_read_write\x18\x01 \x01(\x0b\x32#.Ydb.Query.SerializableModeSettingsH\x00\x12\x39\n\x10online_read_only\x18\x02 \x01(\x0b\x32\x1d.Ydb.Query.OnlineModeSettingsH\x00\x12\x37\n\x0fstale_read_only\x18\x03 \x01(\x0b\x32\x1c.Ydb.Query.StaleModeSettingsH\x00\x12=\n\x12snapshot_read_only\x18\x04 \x01(\x0b\x32\x1f.Ydb.Query.SnapshotModeSettingsH\x00\x12@\n\x13snapshot_read_write\x18\x05 \x01(\x0b\x32!.Ydb.Query.SnapshotRWModeSettingsH\x00\x42\t\n\x07tx_mode\"\x84\x01\n\x12TransactionControl\x12\x18\n\x05tx_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08H\x00\x12\x32\n\x08\x62\x65gin_tx\x18\x02 \x01(\x0b\x32\x1e.Ydb.Query.TransactionSettingsH\x00\x12\x11\n\tcommit_tx\x18\n \x01(\x08\x42\r\n\x0btx_selector\"k\n\x17\x42\x65ginTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x33\n\x0btx_settings\x18\x02 \x01(\x0b\x32\x1e.Ydb.Query.TransactionSettings\"&\n\x0fTransactionMeta\x12\x13\n\x02id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"\x9b\x01\n\x18\x42\x65ginTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12+\n\x07tx_meta\x18\x03 \x01(\x0b\x32\x1a.Ydb.Query.TransactionMeta\"O\n\x18\x43ommitTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x16\n\x05tx_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"o\n\x19\x43ommitTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"Q\n\x1aRollbackTransactionRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x16\n\x05tx_id\x18\x02 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"q\n\x1bRollbackTransactionResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\"?\n\x0cQueryContent\x12!\n\x06syntax\x18\x01 \x01(\x0e\x32\x11.Ydb.Query.Syntax\x12\x0c\n\x04text\x18\x02 \x01(\t\"\xb6\x05\n\x13\x45xecuteQueryRequest\x12\x1b\n\nsession_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12&\n\texec_mode\x18\x02 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12\x31\n\ntx_control\x18\x03 \x01(\x0b\x32\x1d.Ydb.Query.TransactionControl\x12\x30\n\rquery_content\x18\x04 \x01(\x0b\x32\x17.Ydb.Query.QueryContentH\x00\x12\x42\n\nparameters\x18\x06 \x03(\x0b\x32..Ydb.Query.ExecuteQueryRequest.ParametersEntry\x12(\n\nstats_mode\x18\x07 \x01(\x0e\x32\x14.Ydb.Query.StatsMode\x12\x1e\n\x16\x63oncurrent_result_sets\x18\x08 \x01(\x08\x12\x34\n\x19response_part_limit_bytes\x18\t \x01(\x03\x42\x11\xb2\xe6*\r[0; 33554432]\x12\x0f\n\x07pool_id\x18\n \x01(\t\x12!\n\x0fstats_period_ms\x18\x0b \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12=\n\x15schema_inclusion_mode\x18\x0c \x01(\x0e\x32\x1e.Ydb.Query.SchemaInclusionMode\x12\x30\n\x11result_set_format\x18\r \x01(\x0e\x32\x15.Ydb.ResultSet.Format\x12?\n\x15\x61rrow_format_settings\x18\x0e \x01(\x0b\x32 .Ydb.Formats.ArrowFormatSettings\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\x42\x07\n\x05query\"-\n\rResultSetMeta\x12\x1c\n\x07\x63olumns\x18\x01 \x03(\x0b\x32\x0b.Ydb.Column\"\x93\x02\n\x18\x45xecuteQueryResponsePart\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\x10result_set_index\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\"\n\nresult_set\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12.\n\nexec_stats\x18\x05 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\x12+\n\x07tx_meta\x18\x06 \x01(\x0b\x32\x1a.Ydb.Query.TransactionMeta\"\x9e\x03\n\x14\x45xecuteScriptRequest\x12\x39\n\x10operation_params\x18\x01 \x01(\x0b\x32\x1f.Ydb.Operations.OperationParams\x12&\n\texec_mode\x18\x02 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12/\n\x0escript_content\x18\x03 \x01(\x0b\x32\x17.Ydb.Query.QueryContent\x12\x43\n\nparameters\x18\x04 \x03(\x0b\x32/.Ydb.Query.ExecuteScriptRequest.ParametersEntry\x12(\n\nstats_mode\x18\x05 \x01(\x0e\x32\x14.Ydb.Query.StatsMode\x12.\n\x0bresults_ttl\x18\x06 \x01(\x0b\x32\x19.google.protobuf.Duration\x12\x0f\n\x07pool_id\x18\x07 \x01(\t\x1a\x42\n\x0fParametersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x1e\n\x05value\x18\x02 \x01(\x0b\x32\x0f.Ydb.TypedValue:\x02\x38\x01\"\x9f\x02\n\x15\x45xecuteScriptMetadata\x12\x1d\n\x0c\x65xecution_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12*\n\x0b\x65xec_status\x18\x02 \x01(\x0e\x32\x15.Ydb.Query.ExecStatus\x12/\n\x0escript_content\x18\x03 \x01(\x0b\x32\x17.Ydb.Query.QueryContent\x12\x32\n\x10result_sets_meta\x18\x04 \x03(\x0b\x32\x18.Ydb.Query.ResultSetMeta\x12&\n\texec_mode\x18\x05 \x01(\x0e\x32\x13.Ydb.Query.ExecMode\x12.\n\nexec_stats\x18\x06 \x01(\x0b\x32\x1a.Ydb.TableStats.QueryStats\"\x90\x01\n\x19\x46\x65tchScriptResultsRequest\x12\x1d\n\x0coperation_id\x18\x01 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x18\n\x10result_set_index\x18\x02 \x01(\x03\x12\x1c\n\x0b\x66\x65tch_token\x18\x03 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\x12\x1c\n\nrows_limit\x18\x04 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\"\xdb\x01\n\x1a\x46\x65tchScriptResultsResponse\x12)\n\x06status\x18\x01 \x01(\x0e\x32\x19.Ydb.StatusIds.StatusCode\x12\'\n\x06issues\x18\x02 \x03(\x0b\x32\x17.Ydb.Issue.IssueMessage\x12\"\n\x10result_set_index\x18\x03 \x01(\x03\x42\x08\xb2\xe6*\x04>= 0\x12\"\n\nresult_set\x18\x04 \x01(\x0b\x32\x0e.Ydb.ResultSet\x12!\n\x10next_fetch_token\x18\x05 \x01(\tB\x07\xa2\xe6*\x03\x18\x80\x08\"9\n\x06Script\x12/\n\x0escript_content\x18\x01 \x01(\x0b\x32\x17.Ydb.Query.QueryContent*B\n\x06Syntax\x12\x16\n\x12SYNTAX_UNSPECIFIED\x10\x00\x12\x11\n\rSYNTAX_YQL_V1\x10\x01\x12\r\n\tSYNTAX_PG\x10\x02*\x86\x01\n\x08\x45xecMode\x12\x19\n\x15\x45XEC_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0f\x45XEC_MODE_PARSE\x10\n\x12\x16\n\x12\x45XEC_MODE_VALIDATE\x10\x14\x12\x15\n\x11\x45XEC_MODE_EXPLAIN\x10\x1e\x12\x15\n\x11\x45XEC_MODE_EXECUTE\x10\x32\"\x04\x08(\x10(*\x7f\n\tStatsMode\x12\x1a\n\x16STATS_MODE_UNSPECIFIED\x10\x00\x12\x13\n\x0fSTATS_MODE_NONE\x10\n\x12\x14\n\x10STATS_MODE_BASIC\x10\x14\x12\x13\n\x0fSTATS_MODE_FULL\x10\x1e\x12\x16\n\x12STATS_MODE_PROFILE\x10(*\x84\x01\n\x13SchemaInclusionMode\x12%\n!SCHEMA_INCLUSION_MODE_UNSPECIFIED\x10\x00\x12 \n\x1cSCHEMA_INCLUSION_MODE_ALWAYS\x10\x01\x12$\n SCHEMA_INCLUSION_MODE_FIRST_ONLY\x10\x02*\xaa\x01\n\nExecStatus\x12\x1b\n\x17\x45XEC_STATUS_UNSPECIFIED\x10\x00\x12\x18\n\x14\x45XEC_STATUS_STARTING\x10\n\x12\x17\n\x13\x45XEC_STATUS_ABORTED\x10\x14\x12\x19\n\x15\x45XEC_STATUS_CANCELLED\x10\x1e\x12\x19\n\x15\x45XEC_STATUS_COMPLETED\x10(\x12\x16\n\x12\x45XEC_STATUS_FAILED\x10\x32\x42S\n\x14tech.ydb.proto.queryZ8github.com/ydb-platform/ydb-go-genproto/protos/Ydb_Query\xf8\x01\x01\x62\x06proto3'
  ,
  dependencies=[google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,protos_dot_annotations_dot_validation__pb2.DESCRIPTOR,protos_dot_ydb__issue__message__pb2.DESCRIPTOR,protos_dot_ydb__operation__pb2.DESCRIPTOR,protos_dot_ydb__query__stats__pb2.DESCRIPTOR,protos_dot_ydb__status__codes__pb2.DESCRIPTOR,protos_dot_ydb__formats__pb2.DESCRIPTOR,protos_dot_ydb__value__pb2.DESCRIPTOR,])

_SYNTAX = _descriptor.EnumDescriptor(
  name='Syntax',
  full_name='Ydb.Query.Syntax',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SYNTAX_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNTAX_YQL_V1', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SYNTAX_PG', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4345,
  serialized_end=4411,
)
_sym_db.RegisterEnumDescriptor(_SYNTAX)

Syntax = enum_type_wrapper.EnumTypeWrapper(_SYNTAX)
_EXECMODE = _descriptor.EnumDescriptor(
  name='ExecMode',
  full_name='Ydb.Query.ExecMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EXEC_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_MODE_PARSE', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_MODE_VALIDATE', index=2, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_MODE_EXPLAIN', index=3, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_MODE_EXECUTE', index=4, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4414,
  serialized_end=4548,
)
_sym_db.RegisterEnumDescriptor(_EXECMODE)

ExecMode = enum_type_wrapper.EnumTypeWrapper(_EXECMODE)
_STATSMODE = _descriptor.EnumDescriptor(
  name='StatsMode',
  full_name='Ydb.Query.StatsMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='STATS_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_MODE_NONE', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_MODE_BASIC', index=2, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_MODE_FULL', index=3, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='STATS_MODE_PROFILE', index=4, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4550,
  serialized_end=4677,
)
_sym_db.RegisterEnumDescriptor(_STATSMODE)

StatsMode = enum_type_wrapper.EnumTypeWrapper(_STATSMODE)
_SCHEMAINCLUSIONMODE = _descriptor.EnumDescriptor(
  name='SchemaInclusionMode',
  full_name='Ydb.Query.SchemaInclusionMode',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='SCHEMA_INCLUSION_MODE_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEMA_INCLUSION_MODE_ALWAYS', index=1, number=1,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='SCHEMA_INCLUSION_MODE_FIRST_ONLY', index=2, number=2,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4680,
  serialized_end=4812,
)
_sym_db.RegisterEnumDescriptor(_SCHEMAINCLUSIONMODE)

SchemaInclusionMode = enum_type_wrapper.EnumTypeWrapper(_SCHEMAINCLUSIONMODE)
_EXECSTATUS = _descriptor.EnumDescriptor(
  name='ExecStatus',
  full_name='Ydb.Query.ExecStatus',
  filename=None,
  file=DESCRIPTOR,
  create_key=_descriptor._internal_create_key,
  values=[
    _descriptor.EnumValueDescriptor(
      name='EXEC_STATUS_UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_STATUS_STARTING', index=1, number=10,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_STATUS_ABORTED', index=2, number=20,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_STATUS_CANCELLED', index=3, number=30,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_STATUS_COMPLETED', index=4, number=40,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
    _descriptor.EnumValueDescriptor(
      name='EXEC_STATUS_FAILED', index=5, number=50,
      serialized_options=None,
      type=None,
      create_key=_descriptor._internal_create_key),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=4815,
  serialized_end=4985,
)
_sym_db.RegisterEnumDescriptor(_EXECSTATUS)

ExecStatus = enum_type_wrapper.EnumTypeWrapper(_EXECSTATUS)
SYNTAX_UNSPECIFIED = 0
SYNTAX_YQL_V1 = 1
SYNTAX_PG = 2
EXEC_MODE_UNSPECIFIED = 0
EXEC_MODE_PARSE = 10
EXEC_MODE_VALIDATE = 20
EXEC_MODE_EXPLAIN = 30
EXEC_MODE_EXECUTE = 50
STATS_MODE_UNSPECIFIED = 0
STATS_MODE_NONE = 10
STATS_MODE_BASIC = 20
STATS_MODE_FULL = 30
STATS_MODE_PROFILE = 40
SCHEMA_INCLUSION_MODE_UNSPECIFIED = 0
SCHEMA_INCLUSION_MODE_ALWAYS = 1
SCHEMA_INCLUSION_MODE_FIRST_ONLY = 2
EXEC_STATUS_UNSPECIFIED = 0
EXEC_STATUS_STARTING = 10
EXEC_STATUS_ABORTED = 20
EXEC_STATUS_CANCELLED = 30
EXEC_STATUS_COMPLETED = 40
EXEC_STATUS_FAILED = 50



_CREATESESSIONREQUEST = _descriptor.Descriptor(
  name='CreateSessionRequest',
  full_name='Ydb.Query.CreateSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=277,
  serialized_end=299,
)


_CREATESESSIONRESPONSE = _descriptor.Descriptor(
  name='CreateSessionResponse',
  full_name='Ydb.Query.CreateSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.CreateSessionResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.CreateSessionResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Query.CreateSessionResponse.session_id', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='node_id', full_name='Ydb.Query.CreateSessionResponse.node_id', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=302,
  serialized_end=465,
)


_DELETESESSIONREQUEST = _descriptor.Descriptor(
  name='DeleteSessionRequest',
  full_name='Ydb.Query.DeleteSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Query.DeleteSessionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=467,
  serialized_end=518,
)


_DELETESESSIONRESPONSE = _descriptor.Descriptor(
  name='DeleteSessionResponse',
  full_name='Ydb.Query.DeleteSessionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.DeleteSessionResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.DeleteSessionResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=520,
  serialized_end=627,
)


_ATTACHSESSIONREQUEST = _descriptor.Descriptor(
  name='AttachSessionRequest',
  full_name='Ydb.Query.AttachSessionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Query.AttachSessionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=629,
  serialized_end=680,
)


_SESSIONSTATE = _descriptor.Descriptor(
  name='SessionState',
  full_name='Ydb.Query.SessionState',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.SessionState.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.SessionState.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=682,
  serialized_end=780,
)


_SERIALIZABLEMODESETTINGS = _descriptor.Descriptor(
  name='SerializableModeSettings',
  full_name='Ydb.Query.SerializableModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=782,
  serialized_end=808,
)


_ONLINEMODESETTINGS = _descriptor.Descriptor(
  name='OnlineModeSettings',
  full_name='Ydb.Query.OnlineModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='allow_inconsistent_reads', full_name='Ydb.Query.OnlineModeSettings.allow_inconsistent_reads', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=810,
  serialized_end=864,
)


_STALEMODESETTINGS = _descriptor.Descriptor(
  name='StaleModeSettings',
  full_name='Ydb.Query.StaleModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=866,
  serialized_end=885,
)


_SNAPSHOTMODESETTINGS = _descriptor.Descriptor(
  name='SnapshotModeSettings',
  full_name='Ydb.Query.SnapshotModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=887,
  serialized_end=909,
)


_SNAPSHOTRWMODESETTINGS = _descriptor.Descriptor(
  name='SnapshotRWModeSettings',
  full_name='Ydb.Query.SnapshotRWModeSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=911,
  serialized_end=935,
)


_TRANSACTIONSETTINGS = _descriptor.Descriptor(
  name='TransactionSettings',
  full_name='Ydb.Query.TransactionSettings',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='serializable_read_write', full_name='Ydb.Query.TransactionSettings.serializable_read_write', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='online_read_only', full_name='Ydb.Query.TransactionSettings.online_read_only', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stale_read_only', full_name='Ydb.Query.TransactionSettings.stale_read_only', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_read_only', full_name='Ydb.Query.TransactionSettings.snapshot_read_only', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='snapshot_read_write', full_name='Ydb.Query.TransactionSettings.snapshot_read_write', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tx_mode', full_name='Ydb.Query.TransactionSettings.tx_mode',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=938,
  serialized_end=1287,
)


_TRANSACTIONCONTROL = _descriptor.Descriptor(
  name='TransactionControl',
  full_name='Ydb.Query.TransactionControl',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='Ydb.Query.TransactionControl.tx_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='begin_tx', full_name='Ydb.Query.TransactionControl.begin_tx', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='commit_tx', full_name='Ydb.Query.TransactionControl.commit_tx', index=2,
      number=10, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='tx_selector', full_name='Ydb.Query.TransactionControl.tx_selector',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=1290,
  serialized_end=1422,
)


_BEGINTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='BeginTransactionRequest',
  full_name='Ydb.Query.BeginTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Query.BeginTransactionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_settings', full_name='Ydb.Query.BeginTransactionRequest.tx_settings', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1424,
  serialized_end=1531,
)


_TRANSACTIONMETA = _descriptor.Descriptor(
  name='TransactionMeta',
  full_name='Ydb.Query.TransactionMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='Ydb.Query.TransactionMeta.id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1533,
  serialized_end=1571,
)


_BEGINTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='BeginTransactionResponse',
  full_name='Ydb.Query.BeginTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.BeginTransactionResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.BeginTransactionResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_meta', full_name='Ydb.Query.BeginTransactionResponse.tx_meta', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1574,
  serialized_end=1729,
)


_COMMITTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='CommitTransactionRequest',
  full_name='Ydb.Query.CommitTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Query.CommitTransactionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='Ydb.Query.CommitTransactionRequest.tx_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1731,
  serialized_end=1810,
)


_COMMITTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='CommitTransactionResponse',
  full_name='Ydb.Query.CommitTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.CommitTransactionResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.CommitTransactionResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1812,
  serialized_end=1923,
)


_ROLLBACKTRANSACTIONREQUEST = _descriptor.Descriptor(
  name='RollbackTransactionRequest',
  full_name='Ydb.Query.RollbackTransactionRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Query.RollbackTransactionRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_id', full_name='Ydb.Query.RollbackTransactionRequest.tx_id', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1925,
  serialized_end=2006,
)


_ROLLBACKTRANSACTIONRESPONSE = _descriptor.Descriptor(
  name='RollbackTransactionResponse',
  full_name='Ydb.Query.RollbackTransactionResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.RollbackTransactionResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.RollbackTransactionResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2008,
  serialized_end=2121,
)


_QUERYCONTENT = _descriptor.Descriptor(
  name='QueryContent',
  full_name='Ydb.Query.QueryContent',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='syntax', full_name='Ydb.Query.QueryContent.syntax', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='text', full_name='Ydb.Query.QueryContent.text', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2123,
  serialized_end=2186,
)


_EXECUTEQUERYREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='Ydb.Query.ExecuteQueryRequest.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Query.ExecuteQueryRequest.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Query.ExecuteQueryRequest.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2808,
  serialized_end=2874,
)

_EXECUTEQUERYREQUEST = _descriptor.Descriptor(
  name='ExecuteQueryRequest',
  full_name='Ydb.Query.ExecuteQueryRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='session_id', full_name='Ydb.Query.ExecuteQueryRequest.session_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_mode', full_name='Ydb.Query.ExecuteQueryRequest.exec_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_control', full_name='Ydb.Query.ExecuteQueryRequest.tx_control', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='query_content', full_name='Ydb.Query.ExecuteQueryRequest.query_content', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='Ydb.Query.ExecuteQueryRequest.parameters', index=4,
      number=6, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_mode', full_name='Ydb.Query.ExecuteQueryRequest.stats_mode', index=5,
      number=7, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='concurrent_result_sets', full_name='Ydb.Query.ExecuteQueryRequest.concurrent_result_sets', index=6,
      number=8, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='response_part_limit_bytes', full_name='Ydb.Query.ExecuteQueryRequest.response_part_limit_bytes', index=7,
      number=9, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\r[0; 33554432]', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_id', full_name='Ydb.Query.ExecuteQueryRequest.pool_id', index=8,
      number=10, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_period_ms', full_name='Ydb.Query.ExecuteQueryRequest.stats_period_ms', index=9,
      number=11, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='schema_inclusion_mode', full_name='Ydb.Query.ExecuteQueryRequest.schema_inclusion_mode', index=10,
      number=12, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set_format', full_name='Ydb.Query.ExecuteQueryRequest.result_set_format', index=11,
      number=13, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='arrow_format_settings', full_name='Ydb.Query.ExecuteQueryRequest.arrow_format_settings', index=12,
      number=14, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTEQUERYREQUEST_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='query', full_name='Ydb.Query.ExecuteQueryRequest.query',
      index=0, containing_type=None,
      create_key=_descriptor._internal_create_key,
    fields=[]),
  ],
  serialized_start=2189,
  serialized_end=2883,
)


_RESULTSETMETA = _descriptor.Descriptor(
  name='ResultSetMeta',
  full_name='Ydb.Query.ResultSetMeta',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='columns', full_name='Ydb.Query.ResultSetMeta.columns', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2885,
  serialized_end=2930,
)


_EXECUTEQUERYRESPONSEPART = _descriptor.Descriptor(
  name='ExecuteQueryResponsePart',
  full_name='Ydb.Query.ExecuteQueryResponsePart',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.ExecuteQueryResponsePart.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.ExecuteQueryResponsePart.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set_index', full_name='Ydb.Query.ExecuteQueryResponsePart.result_set_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set', full_name='Ydb.Query.ExecuteQueryResponsePart.result_set', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_stats', full_name='Ydb.Query.ExecuteQueryResponsePart.exec_stats', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='tx_meta', full_name='Ydb.Query.ExecuteQueryResponsePart.tx_meta', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2933,
  serialized_end=3208,
)


_EXECUTESCRIPTREQUEST_PARAMETERSENTRY = _descriptor.Descriptor(
  name='ParametersEntry',
  full_name='Ydb.Query.ExecuteScriptRequest.ParametersEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='key', full_name='Ydb.Query.ExecuteScriptRequest.ParametersEntry.key', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='value', full_name='Ydb.Query.ExecuteScriptRequest.ParametersEntry.value', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=b'8\001',
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2808,
  serialized_end=2874,
)

_EXECUTESCRIPTREQUEST = _descriptor.Descriptor(
  name='ExecuteScriptRequest',
  full_name='Ydb.Query.ExecuteScriptRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_params', full_name='Ydb.Query.ExecuteScriptRequest.operation_params', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_mode', full_name='Ydb.Query.ExecuteScriptRequest.exec_mode', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script_content', full_name='Ydb.Query.ExecuteScriptRequest.script_content', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='parameters', full_name='Ydb.Query.ExecuteScriptRequest.parameters', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='stats_mode', full_name='Ydb.Query.ExecuteScriptRequest.stats_mode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='results_ttl', full_name='Ydb.Query.ExecuteScriptRequest.results_ttl', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='pool_id', full_name='Ydb.Query.ExecuteScriptRequest.pool_id', index=6,
      number=7, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[_EXECUTESCRIPTREQUEST_PARAMETERSENTRY, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3211,
  serialized_end=3625,
)


_EXECUTESCRIPTMETADATA = _descriptor.Descriptor(
  name='ExecuteScriptMetadata',
  full_name='Ydb.Query.ExecuteScriptMetadata',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='execution_id', full_name='Ydb.Query.ExecuteScriptMetadata.execution_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_status', full_name='Ydb.Query.ExecuteScriptMetadata.exec_status', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='script_content', full_name='Ydb.Query.ExecuteScriptMetadata.script_content', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_sets_meta', full_name='Ydb.Query.ExecuteScriptMetadata.result_sets_meta', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_mode', full_name='Ydb.Query.ExecuteScriptMetadata.exec_mode', index=4,
      number=5, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='exec_stats', full_name='Ydb.Query.ExecuteScriptMetadata.exec_stats', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3628,
  serialized_end=3915,
)


_FETCHSCRIPTRESULTSREQUEST = _descriptor.Descriptor(
  name='FetchScriptResultsRequest',
  full_name='Ydb.Query.FetchScriptResultsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='operation_id', full_name='Ydb.Query.FetchScriptResultsRequest.operation_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set_index', full_name='Ydb.Query.FetchScriptResultsRequest.result_set_index', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='fetch_token', full_name='Ydb.Query.FetchScriptResultsRequest.fetch_token', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='rows_limit', full_name='Ydb.Query.FetchScriptResultsRequest.rows_limit', index=3,
      number=4, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3918,
  serialized_end=4062,
)


_FETCHSCRIPTRESULTSRESPONSE = _descriptor.Descriptor(
  name='FetchScriptResultsResponse',
  full_name='Ydb.Query.FetchScriptResultsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='status', full_name='Ydb.Query.FetchScriptResultsResponse.status', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='issues', full_name='Ydb.Query.FetchScriptResultsResponse.issues', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set_index', full_name='Ydb.Query.FetchScriptResultsResponse.result_set_index', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\262\346*\004>= 0', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='result_set', full_name='Ydb.Query.FetchScriptResultsResponse.result_set', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
    _descriptor.FieldDescriptor(
      name='next_fetch_token', full_name='Ydb.Query.FetchScriptResultsResponse.next_fetch_token', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=b"".decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=b'\242\346*\003\030\200\010', file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4065,
  serialized_end=4284,
)


_SCRIPT = _descriptor.Descriptor(
  name='Script',
  full_name='Ydb.Query.Script',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  create_key=_descriptor._internal_create_key,
  fields=[
    _descriptor.FieldDescriptor(
      name='script_content', full_name='Ydb.Query.Script.script_content', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR,  create_key=_descriptor._internal_create_key),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=4286,
  serialized_end=4343,
)

_CREATESESSIONRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_CREATESESSIONRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_DELETESESSIONRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_DELETESESSIONRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_SESSIONSTATE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_SESSIONSTATE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_TRANSACTIONSETTINGS.fields_by_name['serializable_read_write'].message_type = _SERIALIZABLEMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['online_read_only'].message_type = _ONLINEMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['stale_read_only'].message_type = _STALEMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_only'].message_type = _SNAPSHOTMODESETTINGS
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_write'].message_type = _SNAPSHOTRWMODESETTINGS
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['serializable_read_write'])
_TRANSACTIONSETTINGS.fields_by_name['serializable_read_write'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['online_read_only'])
_TRANSACTIONSETTINGS.fields_by_name['online_read_only'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['stale_read_only'])
_TRANSACTIONSETTINGS.fields_by_name['stale_read_only'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['snapshot_read_only'])
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_only'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONSETTINGS.oneofs_by_name['tx_mode'].fields.append(
  _TRANSACTIONSETTINGS.fields_by_name['snapshot_read_write'])
_TRANSACTIONSETTINGS.fields_by_name['snapshot_read_write'].containing_oneof = _TRANSACTIONSETTINGS.oneofs_by_name['tx_mode']
_TRANSACTIONCONTROL.fields_by_name['begin_tx'].message_type = _TRANSACTIONSETTINGS
_TRANSACTIONCONTROL.oneofs_by_name['tx_selector'].fields.append(
  _TRANSACTIONCONTROL.fields_by_name['tx_id'])
_TRANSACTIONCONTROL.fields_by_name['tx_id'].containing_oneof = _TRANSACTIONCONTROL.oneofs_by_name['tx_selector']
_TRANSACTIONCONTROL.oneofs_by_name['tx_selector'].fields.append(
  _TRANSACTIONCONTROL.fields_by_name['begin_tx'])
_TRANSACTIONCONTROL.fields_by_name['begin_tx'].containing_oneof = _TRANSACTIONCONTROL.oneofs_by_name['tx_selector']
_BEGINTRANSACTIONREQUEST.fields_by_name['tx_settings'].message_type = _TRANSACTIONSETTINGS
_BEGINTRANSACTIONRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_BEGINTRANSACTIONRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_BEGINTRANSACTIONRESPONSE.fields_by_name['tx_meta'].message_type = _TRANSACTIONMETA
_COMMITTRANSACTIONRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_COMMITTRANSACTIONRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_ROLLBACKTRANSACTIONRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_ROLLBACKTRANSACTIONRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_QUERYCONTENT.fields_by_name['syntax'].enum_type = _SYNTAX
_EXECUTEQUERYREQUEST_PARAMETERSENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_EXECUTEQUERYREQUEST_PARAMETERSENTRY.containing_type = _EXECUTEQUERYREQUEST
_EXECUTEQUERYREQUEST.fields_by_name['exec_mode'].enum_type = _EXECMODE
_EXECUTEQUERYREQUEST.fields_by_name['tx_control'].message_type = _TRANSACTIONCONTROL
_EXECUTEQUERYREQUEST.fields_by_name['query_content'].message_type = _QUERYCONTENT
_EXECUTEQUERYREQUEST.fields_by_name['parameters'].message_type = _EXECUTEQUERYREQUEST_PARAMETERSENTRY
_EXECUTEQUERYREQUEST.fields_by_name['stats_mode'].enum_type = _STATSMODE
_EXECUTEQUERYREQUEST.fields_by_name['schema_inclusion_mode'].enum_type = _SCHEMAINCLUSIONMODE
_EXECUTEQUERYREQUEST.fields_by_name['result_set_format'].enum_type = protos_dot_ydb__value__pb2._RESULTSET_FORMAT
_EXECUTEQUERYREQUEST.fields_by_name['arrow_format_settings'].message_type = protos_dot_ydb__formats__pb2._ARROWFORMATSETTINGS
_EXECUTEQUERYREQUEST.oneofs_by_name['query'].fields.append(
  _EXECUTEQUERYREQUEST.fields_by_name['query_content'])
_EXECUTEQUERYREQUEST.fields_by_name['query_content'].containing_oneof = _EXECUTEQUERYREQUEST.oneofs_by_name['query']
_RESULTSETMETA.fields_by_name['columns'].message_type = protos_dot_ydb__value__pb2._COLUMN
_EXECUTEQUERYRESPONSEPART.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_EXECUTEQUERYRESPONSEPART.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_EXECUTEQUERYRESPONSEPART.fields_by_name['result_set'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_EXECUTEQUERYRESPONSEPART.fields_by_name['exec_stats'].message_type = protos_dot_ydb__query__stats__pb2._QUERYSTATS
_EXECUTEQUERYRESPONSEPART.fields_by_name['tx_meta'].message_type = _TRANSACTIONMETA
_EXECUTESCRIPTREQUEST_PARAMETERSENTRY.fields_by_name['value'].message_type = protos_dot_ydb__value__pb2._TYPEDVALUE
_EXECUTESCRIPTREQUEST_PARAMETERSENTRY.containing_type = _EXECUTESCRIPTREQUEST
_EXECUTESCRIPTREQUEST.fields_by_name['operation_params'].message_type = protos_dot_ydb__operation__pb2._OPERATIONPARAMS
_EXECUTESCRIPTREQUEST.fields_by_name['exec_mode'].enum_type = _EXECMODE
_EXECUTESCRIPTREQUEST.fields_by_name['script_content'].message_type = _QUERYCONTENT
_EXECUTESCRIPTREQUEST.fields_by_name['parameters'].message_type = _EXECUTESCRIPTREQUEST_PARAMETERSENTRY
_EXECUTESCRIPTREQUEST.fields_by_name['stats_mode'].enum_type = _STATSMODE
_EXECUTESCRIPTREQUEST.fields_by_name['results_ttl'].message_type = google_dot_protobuf_dot_duration__pb2._DURATION
_EXECUTESCRIPTMETADATA.fields_by_name['exec_status'].enum_type = _EXECSTATUS
_EXECUTESCRIPTMETADATA.fields_by_name['script_content'].message_type = _QUERYCONTENT
_EXECUTESCRIPTMETADATA.fields_by_name['result_sets_meta'].message_type = _RESULTSETMETA
_EXECUTESCRIPTMETADATA.fields_by_name['exec_mode'].enum_type = _EXECMODE
_EXECUTESCRIPTMETADATA.fields_by_name['exec_stats'].message_type = protos_dot_ydb__query__stats__pb2._QUERYSTATS
_FETCHSCRIPTRESULTSRESPONSE.fields_by_name['status'].enum_type = protos_dot_ydb__status__codes__pb2._STATUSIDS_STATUSCODE
_FETCHSCRIPTRESULTSRESPONSE.fields_by_name['issues'].message_type = protos_dot_ydb__issue__message__pb2._ISSUEMESSAGE
_FETCHSCRIPTRESULTSRESPONSE.fields_by_name['result_set'].message_type = protos_dot_ydb__value__pb2._RESULTSET
_SCRIPT.fields_by_name['script_content'].message_type = _QUERYCONTENT
DESCRIPTOR.message_types_by_name['CreateSessionRequest'] = _CREATESESSIONREQUEST
DESCRIPTOR.message_types_by_name['CreateSessionResponse'] = _CREATESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['DeleteSessionRequest'] = _DELETESESSIONREQUEST
DESCRIPTOR.message_types_by_name['DeleteSessionResponse'] = _DELETESESSIONRESPONSE
DESCRIPTOR.message_types_by_name['AttachSessionRequest'] = _ATTACHSESSIONREQUEST
DESCRIPTOR.message_types_by_name['SessionState'] = _SESSIONSTATE
DESCRIPTOR.message_types_by_name['SerializableModeSettings'] = _SERIALIZABLEMODESETTINGS
DESCRIPTOR.message_types_by_name['OnlineModeSettings'] = _ONLINEMODESETTINGS
DESCRIPTOR.message_types_by_name['StaleModeSettings'] = _STALEMODESETTINGS
DESCRIPTOR.message_types_by_name['SnapshotModeSettings'] = _SNAPSHOTMODESETTINGS
DESCRIPTOR.message_types_by_name['SnapshotRWModeSettings'] = _SNAPSHOTRWMODESETTINGS
DESCRIPTOR.message_types_by_name['TransactionSettings'] = _TRANSACTIONSETTINGS
DESCRIPTOR.message_types_by_name['TransactionControl'] = _TRANSACTIONCONTROL
DESCRIPTOR.message_types_by_name['BeginTransactionRequest'] = _BEGINTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['TransactionMeta'] = _TRANSACTIONMETA
DESCRIPTOR.message_types_by_name['BeginTransactionResponse'] = _BEGINTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['CommitTransactionRequest'] = _COMMITTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['CommitTransactionResponse'] = _COMMITTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['RollbackTransactionRequest'] = _ROLLBACKTRANSACTIONREQUEST
DESCRIPTOR.message_types_by_name['RollbackTransactionResponse'] = _ROLLBACKTRANSACTIONRESPONSE
DESCRIPTOR.message_types_by_name['QueryContent'] = _QUERYCONTENT
DESCRIPTOR.message_types_by_name['ExecuteQueryRequest'] = _EXECUTEQUERYREQUEST
DESCRIPTOR.message_types_by_name['ResultSetMeta'] = _RESULTSETMETA
DESCRIPTOR.message_types_by_name['ExecuteQueryResponsePart'] = _EXECUTEQUERYRESPONSEPART
DESCRIPTOR.message_types_by_name['ExecuteScriptRequest'] = _EXECUTESCRIPTREQUEST
DESCRIPTOR.message_types_by_name['ExecuteScriptMetadata'] = _EXECUTESCRIPTMETADATA
DESCRIPTOR.message_types_by_name['FetchScriptResultsRequest'] = _FETCHSCRIPTRESULTSREQUEST
DESCRIPTOR.message_types_by_name['FetchScriptResultsResponse'] = _FETCHSCRIPTRESULTSRESPONSE
DESCRIPTOR.message_types_by_name['Script'] = _SCRIPT
DESCRIPTOR.enum_types_by_name['Syntax'] = _SYNTAX
DESCRIPTOR.enum_types_by_name['ExecMode'] = _EXECMODE
DESCRIPTOR.enum_types_by_name['StatsMode'] = _STATSMODE
DESCRIPTOR.enum_types_by_name['SchemaInclusionMode'] = _SCHEMAINCLUSIONMODE
DESCRIPTOR.enum_types_by_name['ExecStatus'] = _EXECSTATUS
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CreateSessionRequest = _reflection.GeneratedProtocolMessageType('CreateSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATESESSIONREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.CreateSessionRequest)
  })
_sym_db.RegisterMessage(CreateSessionRequest)

CreateSessionResponse = _reflection.GeneratedProtocolMessageType('CreateSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CREATESESSIONRESPONSE,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.CreateSessionResponse)
  })
_sym_db.RegisterMessage(CreateSessionResponse)

DeleteSessionRequest = _reflection.GeneratedProtocolMessageType('DeleteSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _DELETESESSIONREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.DeleteSessionRequest)
  })
_sym_db.RegisterMessage(DeleteSessionRequest)

DeleteSessionResponse = _reflection.GeneratedProtocolMessageType('DeleteSessionResponse', (_message.Message,), {
  'DESCRIPTOR' : _DELETESESSIONRESPONSE,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.DeleteSessionResponse)
  })
_sym_db.RegisterMessage(DeleteSessionResponse)

AttachSessionRequest = _reflection.GeneratedProtocolMessageType('AttachSessionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ATTACHSESSIONREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.AttachSessionRequest)
  })
_sym_db.RegisterMessage(AttachSessionRequest)

SessionState = _reflection.GeneratedProtocolMessageType('SessionState', (_message.Message,), {
  'DESCRIPTOR' : _SESSIONSTATE,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.SessionState)
  })
_sym_db.RegisterMessage(SessionState)

SerializableModeSettings = _reflection.GeneratedProtocolMessageType('SerializableModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _SERIALIZABLEMODESETTINGS,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.SerializableModeSettings)
  })
_sym_db.RegisterMessage(SerializableModeSettings)

OnlineModeSettings = _reflection.GeneratedProtocolMessageType('OnlineModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _ONLINEMODESETTINGS,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.OnlineModeSettings)
  })
_sym_db.RegisterMessage(OnlineModeSettings)

StaleModeSettings = _reflection.GeneratedProtocolMessageType('StaleModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _STALEMODESETTINGS,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.StaleModeSettings)
  })
_sym_db.RegisterMessage(StaleModeSettings)

SnapshotModeSettings = _reflection.GeneratedProtocolMessageType('SnapshotModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTMODESETTINGS,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.SnapshotModeSettings)
  })
_sym_db.RegisterMessage(SnapshotModeSettings)

SnapshotRWModeSettings = _reflection.GeneratedProtocolMessageType('SnapshotRWModeSettings', (_message.Message,), {
  'DESCRIPTOR' : _SNAPSHOTRWMODESETTINGS,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.SnapshotRWModeSettings)
  })
_sym_db.RegisterMessage(SnapshotRWModeSettings)

TransactionSettings = _reflection.GeneratedProtocolMessageType('TransactionSettings', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONSETTINGS,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.TransactionSettings)
  })
_sym_db.RegisterMessage(TransactionSettings)

TransactionControl = _reflection.GeneratedProtocolMessageType('TransactionControl', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONCONTROL,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.TransactionControl)
  })
_sym_db.RegisterMessage(TransactionControl)

BeginTransactionRequest = _reflection.GeneratedProtocolMessageType('BeginTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _BEGINTRANSACTIONREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.BeginTransactionRequest)
  })
_sym_db.RegisterMessage(BeginTransactionRequest)

TransactionMeta = _reflection.GeneratedProtocolMessageType('TransactionMeta', (_message.Message,), {
  'DESCRIPTOR' : _TRANSACTIONMETA,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.TransactionMeta)
  })
_sym_db.RegisterMessage(TransactionMeta)

BeginTransactionResponse = _reflection.GeneratedProtocolMessageType('BeginTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _BEGINTRANSACTIONRESPONSE,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.BeginTransactionResponse)
  })
_sym_db.RegisterMessage(BeginTransactionResponse)

CommitTransactionRequest = _reflection.GeneratedProtocolMessageType('CommitTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _COMMITTRANSACTIONREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.CommitTransactionRequest)
  })
_sym_db.RegisterMessage(CommitTransactionRequest)

CommitTransactionResponse = _reflection.GeneratedProtocolMessageType('CommitTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMMITTRANSACTIONRESPONSE,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.CommitTransactionResponse)
  })
_sym_db.RegisterMessage(CommitTransactionResponse)

RollbackTransactionRequest = _reflection.GeneratedProtocolMessageType('RollbackTransactionRequest', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKTRANSACTIONREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.RollbackTransactionRequest)
  })
_sym_db.RegisterMessage(RollbackTransactionRequest)

RollbackTransactionResponse = _reflection.GeneratedProtocolMessageType('RollbackTransactionResponse', (_message.Message,), {
  'DESCRIPTOR' : _ROLLBACKTRANSACTIONRESPONSE,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.RollbackTransactionResponse)
  })
_sym_db.RegisterMessage(RollbackTransactionResponse)

QueryContent = _reflection.GeneratedProtocolMessageType('QueryContent', (_message.Message,), {
  'DESCRIPTOR' : _QUERYCONTENT,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.QueryContent)
  })
_sym_db.RegisterMessage(QueryContent)

ExecuteQueryRequest = _reflection.GeneratedProtocolMessageType('ExecuteQueryRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTEQUERYREQUEST_PARAMETERSENTRY,
    '__module__' : 'protos.ydb_query_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Query.ExecuteQueryRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTEQUERYREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.ExecuteQueryRequest)
  })
_sym_db.RegisterMessage(ExecuteQueryRequest)
_sym_db.RegisterMessage(ExecuteQueryRequest.ParametersEntry)

ResultSetMeta = _reflection.GeneratedProtocolMessageType('ResultSetMeta', (_message.Message,), {
  'DESCRIPTOR' : _RESULTSETMETA,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.ResultSetMeta)
  })
_sym_db.RegisterMessage(ResultSetMeta)

ExecuteQueryResponsePart = _reflection.GeneratedProtocolMessageType('ExecuteQueryResponsePart', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTEQUERYRESPONSEPART,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.ExecuteQueryResponsePart)
  })
_sym_db.RegisterMessage(ExecuteQueryResponsePart)

ExecuteScriptRequest = _reflection.GeneratedProtocolMessageType('ExecuteScriptRequest', (_message.Message,), {

  'ParametersEntry' : _reflection.GeneratedProtocolMessageType('ParametersEntry', (_message.Message,), {
    'DESCRIPTOR' : _EXECUTESCRIPTREQUEST_PARAMETERSENTRY,
    '__module__' : 'protos.ydb_query_pb2'
    # @@protoc_insertion_point(class_scope:Ydb.Query.ExecuteScriptRequest.ParametersEntry)
    })
  ,
  'DESCRIPTOR' : _EXECUTESCRIPTREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.ExecuteScriptRequest)
  })
_sym_db.RegisterMessage(ExecuteScriptRequest)
_sym_db.RegisterMessage(ExecuteScriptRequest.ParametersEntry)

ExecuteScriptMetadata = _reflection.GeneratedProtocolMessageType('ExecuteScriptMetadata', (_message.Message,), {
  'DESCRIPTOR' : _EXECUTESCRIPTMETADATA,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.ExecuteScriptMetadata)
  })
_sym_db.RegisterMessage(ExecuteScriptMetadata)

FetchScriptResultsRequest = _reflection.GeneratedProtocolMessageType('FetchScriptResultsRequest', (_message.Message,), {
  'DESCRIPTOR' : _FETCHSCRIPTRESULTSREQUEST,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.FetchScriptResultsRequest)
  })
_sym_db.RegisterMessage(FetchScriptResultsRequest)

FetchScriptResultsResponse = _reflection.GeneratedProtocolMessageType('FetchScriptResultsResponse', (_message.Message,), {
  'DESCRIPTOR' : _FETCHSCRIPTRESULTSRESPONSE,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.FetchScriptResultsResponse)
  })
_sym_db.RegisterMessage(FetchScriptResultsResponse)

Script = _reflection.GeneratedProtocolMessageType('Script', (_message.Message,), {
  'DESCRIPTOR' : _SCRIPT,
  '__module__' : 'protos.ydb_query_pb2'
  # @@protoc_insertion_point(class_scope:Ydb.Query.Script)
  })
_sym_db.RegisterMessage(Script)


DESCRIPTOR._options = None
_CREATESESSIONRESPONSE.fields_by_name['session_id']._options = None
_CREATESESSIONRESPONSE.fields_by_name['node_id']._options = None
_DELETESESSIONREQUEST.fields_by_name['session_id']._options = None
_ATTACHSESSIONREQUEST.fields_by_name['session_id']._options = None
_TRANSACTIONCONTROL.fields_by_name['tx_id']._options = None
_BEGINTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
_TRANSACTIONMETA.fields_by_name['id']._options = None
_COMMITTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
_COMMITTRANSACTIONREQUEST.fields_by_name['tx_id']._options = None
_ROLLBACKTRANSACTIONREQUEST.fields_by_name['session_id']._options = None
_ROLLBACKTRANSACTIONREQUEST.fields_by_name['tx_id']._options = None
_EXECUTEQUERYREQUEST_PARAMETERSENTRY._options = None
_EXECUTEQUERYREQUEST.fields_by_name['session_id']._options = None
_EXECUTEQUERYREQUEST.fields_by_name['response_part_limit_bytes']._options = None
_EXECUTEQUERYREQUEST.fields_by_name['stats_period_ms']._options = None
_EXECUTEQUERYRESPONSEPART.fields_by_name['result_set_index']._options = None
_EXECUTESCRIPTREQUEST_PARAMETERSENTRY._options = None
_EXECUTESCRIPTMETADATA.fields_by_name['execution_id']._options = None
_FETCHSCRIPTRESULTSREQUEST.fields_by_name['operation_id']._options = None
_FETCHSCRIPTRESULTSREQUEST.fields_by_name['fetch_token']._options = None
_FETCHSCRIPTRESULTSREQUEST.fields_by_name['rows_limit']._options = None
_FETCHSCRIPTRESULTSRESPONSE.fields_by_name['result_set_index']._options = None
_FETCHSCRIPTRESULTSRESPONSE.fields_by_name['next_fetch_token']._options = None
# @@protoc_insertion_point(module_scope)



import os.path

import pytest

import ydb
from ydb import issues


@pytest.mark.asyncio
class TestTopicClientControlPlaneAsyncIO:
    async def test_create_topic(self, driver, database):
        client = driver.topic_client

        topic_path = database + "/my-test-topic"

        await client.create_topic(topic_path)

        with pytest.raises(issues.SchemeError):
            # double create is ok - try create topic with bad path
            await client.create_topic(database)

    async def test_drop_topic(self, driver, topic_path):
        client = driver.topic_client

        await client.drop_topic(topic_path)

        with pytest.raises(issues.SchemeError):
            await client.drop_topic(topic_path)

    async def test_describe_topic(self, driver, topic_path: str, topic_consumer):
        res = await driver.topic_client.describe_topic(topic_path)

        assert res.self.name == os.path.basename(topic_path)

        has_consumer = False
        for consumer in res.consumers:
            assert consumer.consumer_stats is not None
            for stat in ["min_partitions_last_read_time", "max_read_time_lag", "max_write_time_lag", "bytes_read"]:
                assert getattr(consumer.consumer_stats, stat, None) is not None
            if consumer.name == topic_consumer:
                has_consumer = True
                break

        assert has_consumer

    async def test_alter_not_existed_topic(self, driver, topic_path):
        client = driver.topic_client

        with pytest.raises(issues.SchemeError):
            await client.alter_topic(topic_path + "-not-exist")

    async def test_alter_existed_topic(self, driver, topic_path):
        client = driver.topic_client

        topic_before = await client.describe_topic(topic_path)

        target_min_active_partitions = topic_before.min_active_partitions + 1
        await client.alter_topic(topic_path, set_min_active_partitions=target_min_active_partitions)

        topic_after = await client.describe_topic(topic_path)
        assert topic_after.min_active_partitions == target_min_active_partitions

    async def test_alter_auto_partitioning_settings(self, driver, topic_path):
        client = driver.topic_client

        topic_before = await client.describe_topic(topic_path)

        expected = topic_before.auto_partitioning_settings

        expected.strategy = ydb.TopicAutoPartitioningStrategy.SCALE_UP

        await client.alter_topic(
            topic_path,
            alter_auto_partitioning_settings=ydb.TopicAlterAutoPartitioningSettings(
                set_strategy=ydb.TopicAutoPartitioningStrategy.SCALE_UP,
            ),
        )

        topic_after = await client.describe_topic(topic_path)

        assert topic_after.auto_partitioning_settings == expected

        expected.up_utilization_percent = 88

        await client.alter_topic(
            topic_path,
            alter_auto_partitioning_settings=ydb.TopicAlterAutoPartitioningSettings(
                set_up_utilization_percent=88,
            ),
        )

        topic_after = await client.describe_topic(topic_path)

        assert topic_after.auto_partitioning_settings == expected


class TestTopicClientControlPlane:
    def test_create_topic(self, driver_sync, database):
        client = driver_sync.topic_client

        topic_path = database + "/my-test-topic"

        client.create_topic(topic_path)

        with pytest.raises(issues.SchemeError):
            # double create is ok - try create topic with bad path
            client.create_topic(database)

    def test_drop_topic(self, driver_sync, topic_path):
        client = driver_sync.topic_client

        client.drop_topic(topic_path)

        with pytest.raises(issues.SchemeError):
            client.drop_topic(topic_path)

    def test_describe_topic(self, driver_sync, topic_path: str, topic_consumer):
        res = driver_sync.topic_client.describe_topic(topic_path)

        assert res.self.name == os.path.basename(topic_path)

        has_consumer = False
        for consumer in res.consumers:
            if consumer.name == topic_consumer:
                has_consumer = True
                break

        assert has_consumer

    def test_alter_not_existed_topic(self, driver_sync, topic_path):
        client = driver_sync.topic_client

        with pytest.raises(issues.SchemeError):
            client.alter_topic(topic_path + "-not-exist")

    def test_alter_existed_topic(self, driver_sync, topic_path):
        client = driver_sync.topic_client

        topic_before = client.describe_topic(topic_path)

        target_min_active_partitions = topic_before.min_active_partitions + 1
        client.alter_topic(topic_path, set_min_active_partitions=target_min_active_partitions)

        topic_after = client.describe_topic(topic_path)
        assert topic_after.min_active_partitions == target_min_active_partitions
